@@ -9,6 +9,7 @@
         dsn => 'dbi:Pg:dbname=test_yancy'
     },
     loader_options => {
+        overwrite_modifications => 1, # If we're running this, we want to rebuild it all
         dump_directory => 't/lib',
         generate_pod => 0,
         moniker_map => sub {
@@ -28,5 +29,9 @@
                 $value;
             \%col_info;
         },
+        rel_name_map => sub {
+            my ( $param ) = @_;
+            return $param->{ remote_moniker };
+        },
     },
 }
